@@ -4,69 +4,97 @@ familiar:::test_all_learners_available(learners=familiar:::.get_available_ranger
 # Don't perform any further tests on CRAN due to time of running the complete test.
 testthat::skip_on_cran()
 
-familiar:::test_all_learners_train_predict_vimp(learners=familiar:::.get_available_ranger_learners(show_general=FALSE),
-                                                hyperparameter_list=list("count"=list("n_tree"=4,
-                                                                                      "sample_size"=1.00,
-                                                                                      "m_try"=0.3,
-                                                                                      "node_size"=5,
-                                                                                      "tree_depth"=5,
-                                                                                      "alpha"=0.1),
-                                                                         "continuous"=list("n_tree"=4,
-                                                                                           "sample_size"=1.00,
-                                                                                           "m_try"=0.3,
-                                                                                           "node_size"=5,
-                                                                                           "tree_depth"=5,
-                                                                                           "alpha"=0.1),
-                                                                         "binomial"=list("n_tree"=4,
-                                                                                         "sample_size"=1.00,
-                                                                                         "m_try"=0.3,
-                                                                                         "node_size"=5,
-                                                                                         "tree_depth"=5,
-                                                                                         "alpha"=0.1),
-                                                                         "multinomial"=list("n_tree"=4,
-                                                                                            "sample_size"=1.00,
-                                                                                            "m_try"=0.3,
-                                                                                            "node_size"=5,
-                                                                                            "tree_depth"=5,
-                                                                                            "alpha"=0.1),
-                                                                         "survival"=list("n_tree"=4,
-                                                                                         "sample_size"=1.00,
-                                                                                         "m_try"=0.3,
-                                                                                         "node_size"=5,
-                                                                                         "tree_depth"=5,
-                                                                                         "alpha"=0.1)))
+familiar:::test_all_learners_train_predict_vimp(
+  learners=familiar:::.get_available_ranger_learners(show_general=FALSE),
+  hyperparameter_list=list(
+    "count"=list(
+      "n_tree"=4,
+      "sample_size"=1.00,
+      "m_try"=0.3,
+      "node_size"=5,
+      "tree_depth"=5,
+      "alpha"=0.1
+    ),
+    "continuous"=list(
+      "n_tree"=4,
+      "sample_size"=1.00,
+      "m_try"=0.3,
+      "node_size"=5,
+      "tree_depth"=5,
+      "alpha"=0.1
+    ),
+    "binomial"=list(
+      "n_tree"=4,
+      "sample_size"=1.00,
+      "m_try"=0.3,
+      "node_size"=5,
+      "tree_depth"=5,
+      "alpha"=0.1
+    ),
+    "multinomial"=list(
+      "n_tree"=4,
+      "sample_size"=1.00,
+      "m_try"=0.3,
+      "node_size"=5,
+      "tree_depth"=5,
+      "alpha"=0.1
+    ),
+    "survival"=list(
+      "n_tree"=4,
+      "sample_size"=1.00,
+      "m_try"=0.3,
+      "node_size"=5,
+      "tree_depth"=5,
+      "alpha"=0.1
+    )
+  )
+)
 
-familiar:::test_all_learners_parallel_train_predict_vimp(learners=familiar:::.get_available_ranger_learners(show_general=FALSE),
-                                                         hyperparameter_list=list("count"=list("n_tree"=4,
-                                                                                               "sample_size"=1.00,
-                                                                                               "m_try"=0.3,
-                                                                                               "node_size"=5,
-                                                                                               "tree_depth"=5,
-                                                                                               "alpha"=0.1),
-                                                                                  "continuous"=list("n_tree"=4,
-                                                                                                    "sample_size"=1.00,
-                                                                                                    "m_try"=0.3,
-                                                                                                    "node_size"=5,
-                                                                                                    "tree_depth"=5,
-                                                                                                    "alpha"=0.1),
-                                                                                  "binomial"=list("n_tree"=4,
-                                                                                                  "sample_size"=1.00,
-                                                                                                  "m_try"=0.3,
-                                                                                                  "node_size"=5,
-                                                                                                  "tree_depth"=5,
-                                                                                                  "alpha"=0.1),
-                                                                                  "multinomial"=list("n_tree"=4,
-                                                                                                     "sample_size"=1.00,
-                                                                                                     "m_try"=0.3,
-                                                                                                     "node_size"=5,
-                                                                                                     "tree_depth"=5,
-                                                                                                     "alpha"=0.1),
-                                                                                  "survival"=list("n_tree"=4,
-                                                                                                  "sample_size"=1.00,
-                                                                                                  "m_try"=0.3,
-                                                                                                  "node_size"=5,
-                                                                                                  "tree_depth"=5,
-                                                                                                  "alpha"=0.1)))
+familiar:::test_all_learners_parallel_train_predict_vimp(
+  learners=familiar:::.get_available_ranger_learners(show_general=FALSE),
+  hyperparameter_list=list(
+    "count"=list(
+      "n_tree"=4,
+      "sample_size"=1.00,
+      "m_try"=0.3,
+      "node_size"=5,
+      "tree_depth"=5,
+      "alpha"=0.1
+    ),
+    "continuous"=list(
+      "n_tree"=4,
+      "sample_size"=1.00,
+      "m_try"=0.3,
+      "node_size"=5,
+      "tree_depth"=5,
+      "alpha"=0.1
+    ),
+    "binomial"=list(
+      "n_tree"=4,
+      "sample_size"=1.00,
+      "m_try"=0.3,
+      "node_size"=5,
+      "tree_depth"=5,
+      "alpha"=0.1
+    ),
+    "multinomial"=list(
+      "n_tree"=4,
+      "sample_size"=1.00,
+      "m_try"=0.3,
+      "node_size"=5,
+      "tree_depth"=5,
+      "alpha"=0.1
+    ),
+    "survival"=list(
+      "n_tree"=4,
+      "sample_size"=1.00,
+      "m_try"=0.3,
+      "node_size"=5,
+      "tree_depth"=5,
+      "alpha"=0.1
+    )
+  )
+)
 
 
 #####Count outcome tests-------------------------------------------------------------
